#
# spec file for package SAPHanaSR
#
# Copyright (c) 2013-2014 SUSE Linux Products GmbH, Nuernberg, Germany.
# Copyright (c) 2014-2016 SUSE Linux GmbH, Nuernberg, Germany.
# Copyright (c) 2017-2020 SUSE LLC.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.
#
# Please submit bugfixes or comments via http://bugs.opensuse.org/

Name:           SAPHanaSR
License:        GPL-2.0
Group:          Productivity/Clustering/HA
AutoReqProv:    on
Summary:        Resource agents to control the HANA database in system replication setup
Version:        0.154.1
Release:        4.14.1
Url:            http://scn.sap.com/community/hana-in-memory/blog/2014/04/04/fail-safe-operation-of-sap-hana-suse-extends-its-high-availability-solution

BuildArch:      noarch

Source0:        %{name}-%{version}.tgz

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

Requires:       pacemaker > 1.1.1
Requires:       resource-agents

# Require crmsh-scripts on SLES 12 SP1+ for the new HAWK wizards
%if 0%{?sle_version} >= 120100
Requires:       crmsh
Requires:       crmsh-scripts >= 2.2.0
Requires:       python3
BuildRequires:  resource-agents
BuildRequires:  crmsh
BuildRequires:  crmsh-scripts
%endif

%package doc
Summary:        Setup Guide for SAPHanaSR
Group:          Productivity/Clustering/HA

%description
The resource agents SAPHana and SAPHanaTopology are responsible for controlling
a SAP HANA Database which is running in system replication (SR) configuration.

For SAP HANA Databases in System Replication only the described or referenced scenarios in
the README file of this package are supported. For any scenario not matching the scenarios
named or referenced in the README file please contact SUSE at SAP LinuxLab (sap-lab@suse.de).

The following SCN blog gives a first overwiew about running SAP HANA in System Replication with
our resource agents:
http://scn.sap.com/community/hana-in-memory/blog/2014/04/04/fail-safe-operation-of-sap-hana-suse-extends-its-high-availability-solution

Authors:
--------
    Fabian Herschel


%description doc
This subpackage includes the Setup Guide and manual pages for getting
SAP HANA system replication under cluster control.


%prep
tar xf %{S:0}

%if 0%{?sle_version} >= 120100
    %define crmscr_path /usr/share/crmsh/scripts/
%endif


%build
gzip man/*


%install
mkdir -p %{buildroot}/usr/sbin
mkdir -p %{buildroot}%{_docdir}/%{name}
mkdir -p %{buildroot}/usr/share/%{name}/icons
mkdir -p %{buildroot}/usr/share/%{name}/tests
mkdir -p %{buildroot}/usr/share/%{name}/samples
mkdir -p %{buildroot}/usr/lib/ocf/resource.d/suse
mkdir -p %{buildroot}/usr/lib/%{name}
mkdir -p %{buildroot}%{_mandir}/man7
mkdir -p %{buildroot}%{_mandir}/man8

# resource agents
install -m 0755 ra/* %{buildroot}/usr/lib/ocf/resource.d/suse/

# HA/DR hook provider
install -m 0644 srHook/SAPHanaSR.py %{buildroot}/usr/share/%{name}/
install -m 0444 srHook/global.ini %{buildroot}/usr/share/%{name}/samples

# icons for SAPHanaSR-monitor
install -m 0444 icons/* %{buildroot}/usr/share/%{name}/icons

# documentation
install -m 0444 doc/* %{buildroot}/%{_docdir}/%{name}

# manual pages
install -m 0444 man/*.7.gz %{buildroot}%{_mandir}/man7
install -m 0444 man/*.8.gz %{buildroot}%{_mandir}/man8

# auxiliary Perl library and test scripts
#install -m 0555 test/SAPHanaSR-testDriver %{buildroot}/usr/share/%{name}/tests
install -m 0555 test/SAPHanaSR-monitor %{buildroot}/usr/sbin
install -m 0555 test/SAPHanaSR-showAttr %{buildroot}/usr/sbin
install -m 0555 test/SAPHanaSR-replay-archive %{buildroot}/usr/sbin
install -m 0555 test/SAPHanaSR-filter %{buildroot}/usr/sbin
install -m 0444 test/SAPHanaSRTools.pm %{buildroot}/usr/lib/%{name}

# crm/hawk wizard files
%if 0%{?sle_version} >= 120100
# SLES 12 SP1+ and HAWK2
install -D -m 0644 wizard/hawk2/saphanasr.yaml %{buildroot}%{crmscr_path}/saphanasr/main.yml
install -D -m 0644 wizard/hawk2/saphanasr_su_po.yaml %{buildroot}%{crmscr_path}/saphanasr-su-po/main.yml
install -D -m 0644 wizard/hawk2/saphanasr_su_co.yaml %{buildroot}%{crmscr_path}/saphanasr-su-co/main.yml
%else
# older versions of SLES and HAWK1
mkdir -p %{buildroot}/srv/www/hawk/config/wizard/templates
mkdir -p %{buildroot}/srv/www/hawk/config/wizard/workflows
install -m 0444 wizard/hawk1/SAPHanaSR.xml   %{buildroot}/srv/www/hawk/config/wizard/templates
install -m 0444 wizard/hawk1/90-SAPHanaSR.xml  %{buildroot}/srv/www/hawk/config/wizard/workflows
%endif


%files
%defattr(-,root,root)
%dir /usr/lib/ocf
%dir /usr/lib/ocf/resource.d
%dir /usr/lib/ocf/resource.d/suse
/usr/lib/ocf/resource.d/suse/*
/usr/share/%{name}
%dir /usr/lib/%{name}
/usr/lib/%{name}/SAPHanaSRTools.pm
%dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/README
%doc %{_docdir}/%{name}/LICENSE
/usr/sbin/SAPHanaSR-monitor
/usr/sbin/SAPHanaSR-showAttr
/usr/sbin/SAPHanaSR-replay-archive
/usr/sbin/SAPHanaSR-filter

# HAWK2 wizard for SLES 12 SP1+
%if 0%{?sle_version} >= 120100
%dir %{crmscr_path}/saphanasr/
%dir %{crmscr_path}/saphanasr-su-po/
%dir %{crmscr_path}/saphanasr-su-co/
%{crmscr_path}/saphanasr/main.yml
%{crmscr_path}/saphanasr-su-po/main.yml
%{crmscr_path}/saphanasr-su-co/main.yml
%else
%dir /srv/www/hawk
%dir /srv/www/hawk/config
%dir /srv/www/hawk/config/wizard
%dir /srv/www/hawk/config/wizard/templates
%dir /srv/www/hawk/config/wizard/workflows
/srv/www/hawk/config/wizard/templates/SAPHanaSR.xml
/srv/www/hawk/config/wizard/workflows/90-SAPHanaSR.xml
%endif


%files doc
%defattr(-,root,root)
%doc %{_docdir}/%{name}/SAPHanaSR-Setup-Guide.pdf
%doc %{_mandir}/man7/ocf_suse_SAPHana.7.gz
%doc %{_mandir}/man7/ocf_suse_SAPHanaTopology.7.gz
%doc %{_mandir}/man7/SAPHanaSR_maintenance_examples.7.gz
%doc %{_mandir}/man7/SAPHanaSR.7.gz
%doc %{_mandir}/man7/SAPHanaSR.py.7.gz
%doc %{_mandir}/man8/SAPHanaSR-monitor.8.gz
%doc %{_mandir}/man8/SAPHanaSR-showAttr.8.gz
%doc %{_mandir}/man8/SAPHanaSR-replay-archive.8.gz


%changelog
* Thu Jul  2 2020 abriel@suse.com
- Version bump to 0.154.1
- log empty site names, but do not generate bad formatted cluster
  attribute name
  (bsc#1173581)
- fix documentation of some parameter defaults
- adjust start/stop/promote/monitor action timeouts to match
  official recommendations
* Thu Nov 21 2019 abriel@suse.com
- restart sapstartsrv service on master nameserver node during
  monitor action, if needed. But NOT during probes.
  (bsc#1157453)
* Fri Nov 15 2019 abriel@suse.com
- Version bump to 0.154.0
- restart sapstartsrv service on master nameserver node
  (bsc#1156150)
* Fri Nov  8 2019 abriel@suse.com
- Version bump to 0.153.3
- The SAPHana resource agent must not down-score a SAP HANA
  Database site, if the landscape status is still 2, which means
  warning.
  Keep high scoring during recovery of the master name server.
  Use a fall-back scoring for the master nameserver nodes, if the
  current roles of the node(s) got lost.
  (bsc#1156067)
- change the shebang line of the HAWK2 templates to python3
  (bsc#1155423)
* Wed Sep 11 2019 abriel@suse.com
- fix typo in a condition statement (bnc#1149829)
* Fri Aug 30 2019 abriel@suse.com
- Version bump to 0.153.2
- rescore the master and fix some log string literals
- Fix bsc#1133866:
  Return $OCF_RUNNING_MASTER (8) instead of $OCF_SUCCESS (0) when
  probing a promoted node.
- If the SAP HANA CALL to 'landscapeHostConfiguration.py' is
  running into a timeout, do a retry of the command. If it still
  fails with a timeout, raise an error but do not set attributes
  to prevent unlogged failovers because of empty or unknown
  attributes.
  (bsc#1134106, bsc#1133024, bsc#1101373)
- Fix bsc#1082974:
  set attribute for remoteNode
- Fix bsc#1139715:
  Using crm-attributes written by a SAP HANA SR provider hook does
  improve the data integrity in special error conditions with
  multiple errors coming in a short time frame.
  Stabilized remote-site detection; SAPHana could now use a site
  specific SR cluster attribute which could be set by a SAP HA/DR
  provider call.
  Add a HA/DR provider hook script, config implementation and man
  page.
  Add parameter "HANA_CALL_TIMEOUT" to the RA configuration
  (SAPHanaTopology and SAPHanaSR) to set a timeout for HANA calls
  like landscapeHostConfiguration.py.
  Implemented "reload" method to allow changing parameters like
  "AUTOMATED_REGISTER"
  Set SWAIT during startup, but only if the attribute is already set
  Set PRIM after promote, but only if the attribute is already set
  The promote function has to set the return code according to the
  checks of the takeover result
  New tool SAPHanaSR-replay-archive, SAPHanaSR-filter and
  SAPHanaSR-showAttr to support SITE attributes
* Fri May 18 2018 imanyugin@suse.com
- Version bump to 0.152.22
- Fix bsc#1091074:
    + Adjust Perl scripts to Perl 5.26.0
    + Remove show_SAPHanaSR_attributes
    + The user is advised to use SAPHanaSR-showAttr instead
- SAPHanaTopology: stricter match for system replication 'mode' in awk
* Wed Jan 31 2018 ro@suse.de
- remove duplicate BuildArch line from specfile
* Mon Nov 20 2017 imanyugin@suse.com
- FATE#323526: adjust HAWK2 Wizards to run on both Python 2 and 3
* Mon Oct 23 2017 imanyugin@suse.com
- Fix bsc#1062267: SAPHanaSR wizard sets IPAddr2 agent's NIC to eth0
* Thu Jul  6 2017 imanyugin@suse.com
- Fix bsc#1045606: update man pages
* Fri Jun  2 2017 imanyugin@suse.com
- Fix bsc#1042154: Scoring race condition between SAPHanaTopology and SAPHana
* Fri May 26 2017 imanyugin@suse.com
- Version bump to 0.152.21
* Wed May  3 2017 imanyugin@suse.com
- Fix bsc#1034685: SAPHanaTopology fails once after updating to 0.152.20
* Wed Feb 15 2017 imanyugin@suse.com
- Version bump to 0.152.20
- Fix bsc#1019117: Fix master scoring of secondary during a takeover
* Tue Dec 20 2016 ilya.manyugin@suse.com
- Version bump to 0.152.19
- Fix bsc#1014397: SAPHanaSR not failing over consistently
- Fix bsc#1008469: SAPHanaSR-monitor reports wrong status colors and error messages
- Add a cluster attribute hana_<SID>_version upon a probe of SAPHanaTopology
- Update man pages
- Change the Setup Guide to contain just the URL to the best practices
- Fix bsc#994753: Tool SAPHanaSR-showAttr fails to read offline cib file correctly
- Fix bsc#1016691: Status file of SAPHanaTopology is not multi instance aware (MCOS)
- Fix bsc#1016936: SAPHanaSR-TestDriver fails to detect the correct status
- Fix bsc#985822: HAWK Wizards are listed as legacy
* Wed Nov  2 2016 imanyugin@suse.com
- Version bump to 0.152.18
- Fix bsc#985474: SAPHanaSR-showAttr shows node ID instead of uname
- Fix bsc#1007825: SAPHanaSR-showAttr fails to show node status
- Fix bsc#1005872: SAPHana Resource Agent handling virtual hostnames
- Fix bsc#1007605: SAPHanaSR no longer ignores DR SR status
* Wed Jun  1 2016 fabian.herschel@suse.com
- bsc#982355 - SAPHanaSR: SAP changed the interface of landscapeHostConfiguration.py beginning with SPS12 rev 120
- bsc#981446 - SAPHanaSR: SAP revokes interface hdbnsutil -sr_state beginning from rev 112.03
* Tue May  3 2016 fabian.herschel@suse.com
- log_attributes are not longer logged to /var/log/fhATTRIBUTES by default
* Fri Apr 29 2016 fabian.herschel@suse.com
- bsc#977644 -  SAPHanaSR: SAP Hana resource with Virtual IP not migrating from master to secondary node correctly
* Tue Nov 24 2015 fabian.herschel@suse.com
- Fix for bsc#954653; SAPHanaSR: Resources SAPHana and SAPHanaTopology not managed correctly by Hawk in SLES12 for SAP
- Use new parameters for hdbnsutil -sr_regsiter for SAP HANA >= SPS110
* Thu Oct  8 2015 fabian.herschel@suse.com
- Fix for bsc#949544; SAPHanaSR needs to handle hanging SAP HANA calls
* Mon Oct  5 2015 fabian.herschel@suse.com
- Fix for bsc#947303; SAPHanaSR: SAPHana resource agent still requires secure store users
* Thu Aug 20 2015 fabian.herschel@suse.com
- Avoid to set local lpt, if accidently the remote host name is empty
* Wed Jul 22 2015 fabian.herschel@suse.com
- Fix for bsc#939039; SAPHanaSR fails to detect remote site name if site names are substring of an other remote site name like SLE and SLEDR
* Tue Jul 14 2015 fabian.herschel@suse.com
- Updated the package version to 0.151 to relfect matching the upstream version
* Mon Jun 29 2015 fabian.herschel@suse.com
- Fix for bsc#935755; SAPHanaSR together with DAA-SAP-Instance does not work as expected
- Fix for bsc#936387; SAPHanaSR fails to work with multi tenant databases
- Fix for bsc#919925; SAPHanaSR: Leaving Node Maintenance stops HANA Resource Agent
* Mon Dec  8 2014 fabian.herschel@suse.com
- Fix for bsc#908861; SAPHanaSR should be tolerant to an additional secondary
  Still only ONE SAPHANA SID in SR per cluster, still two nodes only but
  an additional secondary in a chain (like A=>B->C) could now be ignored
* Tue Nov  4 2014 fabian.herschel@suse.com
- Package version 0.149;
- Fix for bnc#902244; SAPHanaSR fails when hdbnsutil does not return correctly or does report incomplete output
- Fix for bnc#902241; SAPHanaSR fails in cold bootstrap
- Updated Setup-Guide 11/04/2014
* Fri Jun 13 2014 fabian.herschel@suse.com
- Fix for bnc#882474; SAPHanaSR: SAPHanaTopology could now handle broken saphostexec
* Wed Jun  4 2014 fabian.herschel@suse.com
- Package version 0.148; Fate 317181 Resource Agents for SAP HANA System Replication
